"use strict";(self.rspackChunk_jupyter_collaboration_extension=self.rspackChunk_jupyter_collaboration_extension||[]).push([[6],{1926(e,t,r){r.d(t,{$C:()=>u,t3:()=>i,cw:()=>p,bo:()=>c}),r(801);let n=Number.MAX_SAFE_INTEGER;var o=r(1554);let l=Error("Unexpected end of array"),s=Error("Integer out of Range");class f{constructor(e){this.arr=e,this.pos=0}}let u=e=>new f(e),c=e=>{var t;let r;return t=p(e),r=new Uint8Array(e.arr.buffer,e.pos+e.arr.byteOffset,t),e.pos+=t,r},a=e=>e.arr[e.pos++],p=e=>{let t=0,r=1,o=e.arr.length;for(;e.pos<o;){let o=e.arr[e.pos++];if(t+=(127&o)*r,r*=128,o<128)return t;if(t>n)throw s}throw l},i=o.tv?e=>o.tv.decode(c(e)):e=>{let t=p(e);if(0===t)return"";{let r=String.fromCodePoint(a(e));if(--t<100)for(;t--;)r+=String.fromCodePoint(a(e));else for(;t>0;){let n=t<1e4?t:1e4,o=e.arr.subarray(e.pos,e.pos+n);e.pos+=n,r+=String.fromCodePoint.apply(null,o),t-=n}return decodeURIComponent(escape(r))}}},6214(e,t,r){var n=r(801),o=r(1554);class l{constructor(){this.cpos=0,this.cbuf=new Uint8Array(100),this.bufs=[]}}let s=e=>{let t=e.cpos;for(let r=0;r<e.bufs.length;r++)t+=e.bufs[r].length;return t},f=(e,t)=>{let r=e.cbuf.length;e.cpos===r&&(e.bufs.push(e.cbuf),e.cbuf=new Uint8Array(2*r),e.cpos=0),e.cbuf[e.cpos++]=t},u=(e,t)=>{for(;t>127;)f(e,128|127&t),t=n.RI(t/128);f(e,127&t)},c=new Uint8Array(3e4),a=c.length/3,p=o.db&&o.db.encodeInto?(e,t)=>{if(t.length<a){let r=o.db.encodeInto(t,c).written||0;u(e,r);for(let t=0;t<r;t++)f(e,c[t])}else i(e,o.Af(t))}:(e,t)=>{let r=unescape(encodeURIComponent(t)),n=r.length;u(e,n);for(let t=0;t<n;t++)f(e,r.codePointAt(t))},i=(e,t)=>{let r,o,l,s;u(e,t.byteLength),r=e.cbuf.length,o=e.cpos,l=n.jk(r-o,t.length),s=t.length-l,e.cbuf.set(t.subarray(0,l),o),e.cpos+=l,s>0&&(e.bufs.push(e.cbuf),e.cbuf=new Uint8Array(n.T9(2*r,s)),e.cbuf.set(t.subarray(l)),e.cpos=s)};new DataView(new ArrayBuffer(4)),r.d(t,{},{Bw:s,Fo:e=>{let t=new Uint8Array(s(e)),r=0;for(let n=0;n<e.bufs.length;n++){let o=e.bufs[n];t.set(o,r),r+=o.length}return t.set(new Uint8Array(e.cbuf.buffer,0,e.cpos),r),t},Gu:i,Qj:p,xv:()=>new l,zd:u})},801(e,t,r){let n=Math.floor,o=Math.pow;r.d(t,{},{RI:n,T9:(e,t)=>e>t?e:t,jk:(e,t)=>e<t?e:t,n7:o,sj:e=>0!==e?e<0:1/e<0})},1554(e,t,r){let n=String.fromCharCode;n(65535);let o=/^\s*/g,l=/([A-Z])/g,s="u">typeof TextEncoder?new TextEncoder:null,f=s?e=>s.encode(e):e=>{let t=unescape(encodeURIComponent(e)),r=t.length,n=new Uint8Array(r);for(let e=0;e<r;e++)n[e]=t.codePointAt(e);return n},u="u"<typeof TextDecoder?null:new TextDecoder("utf-8",{fatal:!0,ignoreBOM:!0});u&&1===u.decode(new Uint8Array).length&&(u=null),r.d(t,{tv:()=>u},{Af:f,QV:n,db:s,jN:(e,t)=>e.replace(l,e=>`${t}${e.toLowerCase()}`).replace(o,"")})}}]);